<!-- Imports polymer -->
<link rel="import" href="../polymer/polymer.html">
<link rel="import" href="../app-route/app-route.html">
<link rel="import" href="../app-route/app-location.html">
<link rel="import" href="../iron-image/iron-image.html">
<link rel="import" href="../iron-ajax/iron-ajax.html">

<dom-module id="palmetto-elements-confirmation-form">

    <template>


        <style is="custom-style" include="iron-flex iron-flex-alignment palmetto-framework-styles">

            :host {
                display: block;
                height: 100%;
            }

            .form-container {
                height: 279px;
            }


            .icn-check {
                width: 80px;
                height: 80px;
                object-fit: contain;
            }

            .login-btn {
                height: 40px;
                font-size: 14px;
            }

            .back-container {
                width: 56px;
            }

            .page-title-container {
                height: 40px;
            }

            .page-title {
                font-size: 20px;
                color: rgba(0, 0, 0, 0.87);
            }

            .page-desc {
                font-size: 16px;
                line-height: 1.31;
                letter-spacing: 0.1px;
                color: rgba(0, 0, 0, 0.54);
            }

            .page-desc-container {
                text-align: center;
                padding: 0 40px;
                width: 100%;
            }


        </style>

        <iron-ajax method="GET" id="confirmAccount" url="/api/accounts/confirm" handle-as="json" on-response="handleResponse" on-error="handleError"></iron-ajax>


        <iron-pages selected="[[ironPagesSelected]]" class="full-height" attr-for-selected="key" fallback-selection="main">

            <div class="layout vertical full-height form-container" key="main">

                <template is="dom-if" if="[[successfulLogin]]" restamp="true">
                    <div class="layout vertical full-height center vertical-center">
                        <iron-image src="/images/icons/misc/icn-check.svg" class="icn-check" preload sizing="cover"></iron-image>
                        <div class="height-20"></div>
                        <span class="page-title"> Email verified </span>
                        <div class="height-10"></div>
                        <div class="page-desc-container">
                            <span class="page-desc">Your email has been verified. Allow for 1-2 business days for processing and review of your account.</span>
                        </div>

                        <div class="height-10"></div>
                        <div class="login-section-break"></div>

                        <div class="layout horizontal center-justified">
                            <a on-tap="_reset" href="/#/" class="bottom-link" on-tap="forgotpassword">Return to login</a>
                        </div>
                    </div>

                </template>

                <template is="dom-if" if="[[!successfulLogin]]" restamp="true">

                    <div class="layout vertical flex center">
                        <div class="height-20"></div>
                        <span class="page-desc"> Verifying email, please wait ... </span>
                        <div class="height-10"></div>
                    </div>

                </template>
            </div>


            <div class="layout vertical full-height form-container" key="error">
                <div class="layout vertical full-height center vertical-center">
                    <div class="height-20"></div>
                    <div class="height-10"></div>
                    <div class="page-desc-container">
                        <span class="page-desc">An error occured.</span>
                    </div>

                    <div class="height-10"></div>
                </div>
            </div>


        </iron-pages>

    </template>

    <script>

        Polymer({

            is: 'palmetto-elements-confirmation-form',

            properties: {
                successfulLogin: {
                    type: Boolean,
                    value: false,
                },
            },

            ready: function(){
                //Check on ready if the load is the verifyAccount page (Meaning they clicked on this link)
                // if(this.route.path.indexOf("/verifyAccount") > -1)
                // {
                //     // Now build the ajax to give to the backend and generate the request
                //     // var params = this.route.path.substring(this.route.path.indexOf("?"));
                //     // this.$.confirmAccount.url += params;
                //     // this.$.confirmAccount.generateRequest();
                // }

                var obj = this.getJsonFromUrl(window.location);
                if(!obj.token) {
                    this.set("ironPagesSelected", "error");
                    return;
                }

                if(!obj.uid) {
                    this.set("ironPagesSelected", "error")
                    return;
                }

                this.$.confirmAccount.params = {
                    "uid": obj.uid,
                    "token": obj.token
                };

                this.$.confirmAccount.generateRequest();
            },

            getJsonFromUrl: function(hashBased) {
                var query;
                if(hashBased) {
                    var pos = location.href.indexOf("?");
                    if(pos==-1) return [];
                    query = location.href.substr(pos+1);
                } else {
                    query = location.search.substr(1);
                }
                var result = {};
                query.split("&").forEach(function(part) {
                    if(!part) return;
                    part = part.split("+").join(" "); // replace every + with space, regexp-free version
                    var eq = part.indexOf("=");
                    var key = eq>-1 ? part.substr(0,eq) : part;
                    var val = eq>-1 ? decodeURIComponent(part.substr(eq+1)) : "";
                    var from = key.indexOf("[");
                    if(from==-1) result[decodeURIComponent(key)] = val;
                    else {
                    var to = key.indexOf("]",from);
                    var index = decodeURIComponent(key.substring(from+1,to));
                    key = decodeURIComponent(key.substring(0,from));
                    if(!result[key]) result[key] = [];
                    if(!index) result[key].push(val);
                    else result[key][index] = val;
                    }
                });
                return result;
            },

            handleResponse: function(e){

                if ( e.detail.status == 200 ) {
                    this.set("successfulLogin", true);
                }
                else {
                    this.set("successfulLogin", false);
                }
            },

            handleError: function(e){
                this.set("ironPagesSelected", "error");
            },
        });
    </script>

</dom-module>
